@@ -1,4 +1,4 @@
-plot.tri<-function(tri.obj,add=F,...)
+plot.tri<-function(tri.obj,add=F,xlim=range(tri.obj$x),ylim=range(tri.obj$y),...)
 {
   if(!inherits(tri.obj,"tri"))
     stop("tri.obj must be of class \"tri\"")
@@ -23,7 +23,7 @@ plot.tri<-function(tri.obj,add=F,...)
   if(!add)
     {
       plot.new()
-      plot.window(xlim=range(tri.obj$x),ylim=range(tri.obj$y),"")
+      plot.window(xlim=xlim,ylim=ylim,"")
     }
   for (i in 1:tri.obj$n)
     {
